@@ -5,6 +5,7 @@
 
 from __future__ import annotations
 
+import sys
 from abc import ABC, abstractmethod
 from copy import copy
 from decimal import Decimal
@@ -12,7 +13,7 @@ from io import BytesIO
 from itertools import zip_longest
 from pathlib import Path
 from shutil import copyfileobj
-from typing import Any, BinaryIO, Callable, NamedTuple, TypeVar, cast
+from typing import Any, BinaryIO, Callable, NamedTuple, TypeVar, Union, cast
 
 from PIL import Image
 from PIL.ImageCms import ImageCmsProfile
@@ -35,6 +36,17 @@ from pikepdf.models import _transcoding
 
 T = TypeVar('T')
 
+if sys.version_info >= (3, 9):
+    RGBDecodeArray = tuple[float, float, float, float, float, float]
+    GrayDecodeArray = tuple[float, float]
+    CMYKDecodeArray = tuple[float, float, float, float, float, float, float, float]
+    DecodeArray = Union[RGBDecodeArray, GrayDecodeArray, CMYKDecodeArray]
+else:
+    RGBDecodeArray = Any
+    GrayDecodeArray = Any
+    CMYKDecodeArray = Any
+    DecodeArray = Any
+
 
 class UnsupportedImageTypeError(Exception):
     """This image is formatted in a way pikepdf does not supported."""
@@ -150,6 +162,29 @@ class PdfImageBase(ABC):
         """List of names of the filters that we applied to encode this image."""
         return self._metadata('Filter', _array_str, [])
 
+    @property
+    def _decode_array(self) -> DecodeArray:
+        """Extract the /Decode array."""
+        decode: list = self._metadata('Decode', _ensure_list, [])
+        if decode and len(decode) in (2, 6, 8):
+            return cast(DecodeArray, tuple(float(value) for value in decode))
+
+        if self.colorspace in ('/DeviceGray', '/CalGray'):
+            return (0.0, 1.0)
+        if self.colorspace == ('/DeviceRGB', '/CalRGB'):
+            return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
+        if self.colorspace == '/DeviceCMYK':
+            return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
+        if self.colorspace == '/ICCBased':
+            if self._approx_mode_from_icc() == 'L':
+                return (0.0, 1.0)
+            if self._approx_mode_from_icc() == 'RGB':
+                return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
+
+        raise NotImplementedError(
+            "Don't how to retrieve default /Decode array for image" + repr(self)
+        )
+
     @property
     def decode_parms(self):
         """List of the /DecodeParms, arguments to filters."""
@@ -456,7 +491,7 @@ class PdfImage(PdfImageBase):
         obj_copy.DecodeParms = Array(self.decode_parms[:n])
         return obj_copy.read_bytes(StreamDecodeLevel.specialized), self.filters[n:]
 
-    def _extract_direct(self, *, stream: BinaryIO) -> str:
+    def _extract_direct(self, *, stream: BinaryIO) -> str | None:
         """Attempt to extract the image directly to a usable image file.
 
         If there is no way to extract the image without decompressing or
@@ -508,7 +543,7 @@ class PdfImage(PdfImageBase):
             stream.write(data)
             return '.jpg'
 
-        raise NotExtractableError()
+        return None
 
     def _extract_transcoded_1248bits(self) -> Image.Image:
         """Extract an image when there are 1/2/4/8 bits packed in byte data."""
@@ -607,10 +642,9 @@ class PdfImage(PdfImageBase):
         Returns:
             The file format extension.
         """
-        try:
-            return self._extract_direct(stream=stream)
-        except NotExtractableError:
-            pass
+        direct_extraction = self._extract_direct(stream=stream)
+        if direct_extraction:
+            return direct_extraction
 
         im = None
         try:
@@ -695,13 +729,11 @@ class PdfImage(PdfImageBase):
 
         Caller must close the image.
         """
-        try:
-            bio = BytesIO()
-            self._extract_direct(stream=bio)
+        bio = BytesIO()
+        direct_extraction = self._extract_direct(stream=bio)
+        if direct_extraction:
             bio.seek(0)
             return Image.open(bio)
-        except NotExtractableError:
-            pass
 
         im = self._extract_transcoded()
         if not im:
@@ -720,7 +752,6 @@ class PdfImage(PdfImageBase):
         expected_defaults = [
             ("/EncodedByteAlign", False),
             ("/EndOfLine", False),
-            ("/EndOfBlock", True),
         ]
         for name, val in expected_defaults:
             if self.decode_parms[0].get(name, val) != val:
@@ -737,7 +768,8 @@ class PdfImage(PdfImageBase):
             t4_options = 1
         else:
             ccitt_group = 3  # Group 3 1-D
-        _black_is_one = self.decode_parms[0].get("/BlackIs1", False)
+        black_is_one = self.decode_parms[0].get("/BlackIs1", False)
+        decode = self._decode_array
         # PDF spec says:
         # BlackIs1: A flag indicating whether 1 bits shall be interpreted as black
         # pixels and 0 bits as white pixels, the reverse of the normal
@@ -745,17 +777,23 @@ class PdfImage(PdfImageBase):
         # TIFF spec says:
         # use 0 for white_is_zero (=> black is 1) MINISWHITE
         # use 1 for black_is_zero (=> white is 1) MINISBLACK
-        # However, despite the documentation, it seems PDF viewers treat
-        # photometry as 0 when ccitt is involved.
-        # For example see
-        # https://gitlab.gnome.org/GNOME/evince/-/blob/main/backend/tiff/tiff2ps.c#L852-865
-        photometry = 0
+        photometry = 1 if black_is_one else 0
+
+        # If Decode is [1, 0] then the photometry is inverted
+        if len(decode) == 2 and decode == (1.0, 0.0):
+            photometry = 1 - photometry
 
         img_size = len(data)
         if icc is None:
             icc = b''
+
         return _transcoding.generate_ccitt_header(
-            self.size, img_size, ccitt_group, t4_options, photometry, icc
+            self.size,
+            data_length=img_size,
+            ccitt_group=ccitt_group,
+            t4_options=t4_options,
+            photometry=photometry,
+            icc=icc,
         )
 
     def show(self):  # pragma: no cover
@@ -766,8 +804,12 @@ class PdfImage(PdfImageBase):
         self._pdf_source = pdf
 
     def __repr__(self):
+        try:
+            mode = self.mode
+        except NotImplementedError:
+            mode = '?'
         return (
-            f'<pikepdf.PdfImage image mode={self.mode} '
+            f'<pikepdf.PdfImage image mode={mode} '
             f'size={self.width}x{self.height} at {hex(id(self))}>'
         )
 
@@ -800,13 +842,16 @@ class PdfJpxImage(PdfImage):
             and self._jpxpil == other._jpxpil
         )
 
-    def _extract_direct(self, *, stream: BinaryIO):
+    def _extract_direct(self, *, stream: BinaryIO) -> str | None:
         data, filters = self._remove_simple_filters()
         if filters != ['/JPXDecode']:
-            raise UnsupportedImageTypeError(self.filters)
+            return None
         stream.write(data)
         return '.jp2'
 
+    def _extract_transcoded(self) -> Image.Image:
+        return super()._extract_transcoded()
+
     @property
     def _colorspaces(self):
         """Return the effective colorspace of a JPEG 2000 image.
